The type of species for a certain veterinary product (e.g. sheep, dog, cattle, and poultry).
Usage
dpd_vet_species(id, lang = c("en", "fr"))The type of species for a certain veterinary product (e.g. sheep, dog, cattle, and poultry).
dpd_vet_species(id, lang = c("en", "fr"))